# Octopus

## Single Arm Control

This environment is the testcase for simplest one-arm control.

- `OctoArmSingle-v0` [Alpha]

## Multi Arm Control

- `OctoFlat-v0` [Alpha]

## Advanced

The goal of this environment is to control 8 arms of the octopus attached to the body, and move towards the targeted location.

- `OctoReach-v0` [Working in Process]
- `OctoSwim-v0` [Working in Process]
- `OctoHunt-v0` [Working in Process]
